==> odoo_19.0.20251008.zip: odoo-19.0.post20251008/odoo/addons/hr_work_entry/static/src/components/class_many2many_avatar_employee_field/many2many_avatar_employee_error_field.js <==
import { registry } from "@web/core/registry";
import {
    Many2ManyTagsAvatarEmployeeField,
    many2ManyTagsAvatarEmployeeField,
} from "@hr/views/fields/many2many_avatar_employee_field/many2many_avatar_employee_field";
import { Many2ManyAvatarUserTagsList } from "@mail/views/web/fields/many2many_avatar_user_field/many2many_avatar_user_field";

export class Many2ManyAvatarUserTagsListError extends Many2ManyAvatarUserTagsList {
    static template = "hr_work_entry.Many2ManyAvatarUserTagsListError";
}

export class Many2ManyTagsAvatarEmployeeErrorField extends Many2ManyTagsAvatarEmployeeField {
    static props = {
        ...Many2ManyTagsAvatarEmployeeField.props,
        inErrorField: { type: String, optional: true },
    };
    static components = {
        ...Many2ManyTagsAvatarEmployeeField.components,
        TagsList: Many2ManyAvatarUserTagsListError,
    };

    /**
     * @override
     */
    getTagProps(record) {
        return {
            ...super.getTagProps(record),
            inError: this.props.record.data[this.props.inErrorField].currentIds.includes(
                record.resId
            ),
        };
    }
}

export const many2ManyTagsAvatarEmployeeErrorField = {
    ...many2ManyTagsAvatarEmployeeField,
    component: Many2ManyTagsAvatarEmployeeErrorField,
    extractProps: (fieldInfo, dynamicInfo) => ({
        ...many2ManyTagsAvatarEmployeeField.extractProps(fieldInfo, dynamicInfo),
        inErrorField: fieldInfo.attrs.in_error,
    }),
};

registry
    .category("fields")
    .add("many2many_avatar_employee_class", many2ManyTagsAvatarEmployeeErrorField);

==> odoo_19.1a1.20251205.zip: odoo-19.1a1.post20251205/odoo/addons/hr_work_entry/static/src/components/class_many2many_avatar_employee_field/many2many_avatar_employee_error_field.js <==
import { registry } from "@web/core/registry";
import {
    Many2ManyTagsAvatarEmployeeField,
    many2ManyTagsAvatarEmployeeField,
} from "@hr/views/fields/many2many_avatar_employee_field/many2many_avatar_employee_field";
import { Component } from "@odoo/owl";
import { AvatarTag } from "@web/core/tags_list/avatar_tag";

class EmployeeErrorTag extends Component {
    static template = "hr_work_entry.EmployeeErrorTag";
    static components = { AvatarTag };
    static props = ["imageUrl", "inError", "onAvatarClick", "onDelete", "text", "tooltip"];
}

export class Many2ManyTagsAvatarEmployeeErrorField extends Many2ManyTagsAvatarEmployeeField {
    static props = {
        ...Many2ManyTagsAvatarEmployeeField.props,
        inErrorField: { type: String, optional: true },
    };
    static components = {
        ...Many2ManyTagsAvatarEmployeeField.components,
        Tag: EmployeeErrorTag,
    };

    /**
     * @override
     */
    getTagProps(record) {
        return {
            ...super.getTagProps(record),
            inError: this.props.record.data[this.props.inErrorField].currentIds.includes(
                record.resId
            ),
        };
    }
}

export const many2ManyTagsAvatarEmployeeErrorField = {
    ...many2ManyTagsAvatarEmployeeField,
    component: Many2ManyTagsAvatarEmployeeErrorField,
    extractProps: (fieldInfo, dynamicInfo) => ({
        ...many2ManyTagsAvatarEmployeeField.extractProps(fieldInfo, dynamicInfo),
        inErrorField: fieldInfo.attrs.in_error,
    }),
};

registry
    .category("fields")
    .add("many2many_avatar_employee_class", many2ManyTagsAvatarEmployeeErrorField);
